schedule property
When the alarm fires, or null for a countdown timer (see countdownDuration).
Implementation
final AlarmSchedule? schedule;
When the alarm fires, or null for a countdown timer (see countdownDuration).
final AlarmSchedule? schedule;